@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #
-# Performs a release of Review Board. This can only be run by the core
+# Performs a release of RBTools. This can only be run by the core
 # developers with release permissions.
 #
 
@@ -13,21 +13,22 @@ import sys
 import tempfile
 import urllib2
 
+from fabazon.s3 import S3Bucket
+
 sys.path.insert(0, os.path.join(os.path.dirname(__file__), "..", ".."))
 from rbtools import __version__, __version_info__, is_release
 
 
-PY_VERSIONS = ["2.4", "2.5", "2.6", "2.7"]
+PY_VERSIONS = ["2.5", "2.6", "2.7"]
 
 LATEST_PY_VERSION = PY_VERSIONS[-1]
 
 PACKAGE_NAME = 'RBTools'
 
-RELEASES_URL = \
-    'reviewboard.org:/var/www/downloads.reviewboard.org/' \
-    'htdocs/releases/%s/%s.%s/' % (PACKAGE_NAME,
-                                   __version_info__[0],
-                                   __version_info__[1])
+RELEASES_BUCKET_NAME = 'downloads.reviewboard.org'
+RELEASES_BUCKET_KEY = '/releases/%s/%s.%s/' % (PACKAGE_NAME,
+                                               __version_info__[0],
+                                               __version_info__[1])
 
 RBWEBSITE_API_URL = 'http://www.reviewboard.org/api/'
 RELEASES_API_URL = '%sproducts/rbtools/releases/' % RBWEBSITE_API_URL
@@ -89,7 +90,7 @@ def execute(cmdline):
     return s
 
 
-def run_setup(target, pyver = LATEST_PY_VERSION):
+def run_setup(target, pyver=LATEST_PY_VERSION):
     execute("python%s ./setup.py release %s" % (pyver, target))
 
 
@@ -104,20 +105,21 @@ def clone_git_tree(git_dir):
 
 def build_targets():
     for pyver in PY_VERSIONS:
-        run_setup("bdist_egg", pyver)
-        built_files.append("dist/%s-%s-py%s.egg" %
-                           (PACKAGE_NAME, __version__, pyver))
+        run_setup('bdist_egg', pyver)
+        built_files.append(('dist/%s-%s-py%s.egg'
+                            % (PACKAGE_NAME, __version__, pyver),
+                            'application/octet-stream'))
 
-    run_setup("sdist")
-    built_files.append("dist/%s-%s.tar.gz" %
-                       (PACKAGE_NAME, __version__))
+    run_setup('sdist')
+    built_files.append(('dist/%s-%s.tar.gz' % (PACKAGE_NAME, __version__),
+                        'application/x-tar'))
 
 
 def build_checksums():
     sha_filename = 'dist/%s-%s.sha256sum' % (PACKAGE_NAME, __version__)
     out_f = open(sha_filename, 'w')
 
-    for filename in built_files:
+    for filename, mimetype in built_files:
         m = hashlib.sha256()
 
         in_f = open(filename, 'r')
@@ -127,11 +129,24 @@ def build_checksums():
         out_f.write('%s  %s\n' % (m.hexdigest(), os.path.basename(filename)))
 
     out_f.close()
-    built_files.append(sha_filename)
+    built_files.append((sha_filename, 'text/plain'))
 
 
 def upload_files():
-    execute("scp %s %s" % (" ".join(built_files), RELEASES_URL))
+    bucket = S3Bucket(RELEASES_BUCKET_NAME)
+
+    for filename, mimetype in built_files:
+        bucket.upload(filename,
+                      '%s/%s' % (RELEASES_BUCKET_KEY,
+                                 filename.split('/')[-1]),
+                      mimetype=mimetype,
+                      public=True)
+
+    bucket.upload_directory_index(RELEASES_BUCKET_KEY)
+
+    # This may be a new directory, so rebuild the parent as well.
+    parent_key = '/'.join(RELEASES_BUCKET_KEY.split('/')[:-2])
+    bucket.upload_directory_index(parent_key)
 
 
 def tag_release():
@@ -148,8 +163,9 @@ def register_release():
         'major_version': __version_info__[0],
         'minor_version': __version_info__[1],
         'micro_version': __version_info__[2],
-        'release_type': __version_info__[3],
-        'release_num': __version_info__[4],
+        'patch_version': __version_info__[3],
+        'release_type': __version_info__[4],
+        'release_num': __version_info__[5],
         'scm_revision': scm_revision,
     }
 
@@ -189,14 +205,13 @@ def register_release():
 def main():
     if not os.path.exists("setup.py"):
         sys.stderr.write("This must be run from the root of the "
-                         "Djblets tree.\n")
+                         "RBTools tree.\n")
         sys.exit(1)
 
     load_config()
 
     if not is_release():
-        sys.stderr.write('This has not been marked as a release in '
-                         'rbtools/__init__.py\n')
+        sys.stderr.write("This version is not listed as a release.\n")
         sys.exit(1)
 
     cur_dir = os.getcwd()
